@@ -41,6 +41,7 @@
 #include "extern.h"
 #include <rmt.h>
 #include <rmt-command.h>
+#include "configmake.h"
 
 enum cpio_options {
   NO_ABSOLUTE_FILENAMES_OPTION=256,
@@ -606,7 +607,7 @@ process_args (int argc, char *argv[])
   xstat = lstat;
 
   if (argp_parse (&argp, argc, argv, ARGP_IN_ORDER|ARGP_NO_HELP, &index, NULL))
-    exit (1); 
+    exit (PAXEXIT_FAILURE); 
 
   /* Do error checking and look at other args.  */
 
@@ -795,7 +796,7 @@ main (int argc, char *argv[])
   (*copy_function) ();
 
   if (archive_des >= 0 && rmtclose (archive_des) == -1)
-    error (1, errno, _("error closing archive"));
+    error (PAXEXIT_FAILURE, errno, _("error closing archive"));
 
-  exit (0);
+  pax_exit ();
 }
